| get_local | R Documentation |
.Rdat fileCreate a file path from dir and file using file.path() and
load the object into the local environment while returning it.
get_local() assumes that there is only one object in the .Rdat file.
The utility of this function comes from being able to quickly load
an R object that was saved as an .Rdat into a function argument without
having to save it in your work space.
get_local(file, dir = file.path(hakedata_wd(), "extractedData"))
file |
A file path for either an existing file or a file that will be written to the disk by the given function. Paths can be either full or relative. |
dir |
The path to a directory. |
Kelli F. Johnson
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.