| plot_theme | R Documentation |
themeCreate a special theme for hake plots when plotting using the
ggplot functions.
plot_theme()
A theme object with specific
instructions on how to create plots for this repository.
Kelli F. Johnson
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.