View source: R/weight_at_age-.R
| weight_at_age_wide | R Documentation |
Take the long-format, which is indicative of raw data, weight-at-age data and make a wide data frame based on ages such that the data frame can be written for Stock Synthesis.
weight_at_age_wide(dat, value = c("weight", "length", "count"), maxage = 15)
dat |
A data frame created from
|
value |
A character value specifying which type of data you are
interested in. The options include |
maxage |
The age of the plus-group bin. The default is 15 years old. This age and all older ages will be combined into a single age bin.. |
A data frame with the first six columns pertaining to metadata,
i.e., #Yr, seas, gender, GP, bseas, and fleet, and additional columns
pertaining to each age starting with age zero up to the maximum age
supplied with the argument maxage. Ages for which there were no
samples are filled with NA. If value = "count", then
the data frame will return sample sizes for each age rather than mean
weight- or length-at-age.
Ian G. Taylor
weight_at_age_read()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.